/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.controllers;

import org.pepstock.charba.client.Controller;
import org.pepstock.charba.client.commons.Checker;

/**
 * Abstract implementation of a controller.
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
public abstract class AbstractController implements Controller {

	private final ControllerType type;

	/**
	 * Creates the controller by its type.
	 * 
	 * @param type the type of this controller.
	 */
	protected AbstractController(ControllerType type) {
		// checks if the controller is consistent
		this.type = Checker.checkAndGetIfValid(type, "Controller type argument");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.Controller#getType()
	 */
	@Override
	public final ControllerType getType() {
		return type;
	}

}
