/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.intl;

/**
 * Enumerates the region or country identifiers which can be used to create and manage locale.
 * 
 * @author Andrea "Stock" Stocchero
 */
public enum Region implements IsLocaleItem
{
	/**
	 * International key, to use for localization, for <b>Afghanistan</b> region.
	 */
	AFGHANISTAN("AF", "Afghanistan"),

	/**
	 * International key, to use for localization, for <b>Albania</b> region.
	 */
	ALBANIA("AL", "Albania"),

	/**
	 * International key, to use for localization, for <b>Algeria</b> region.
	 */
	ALGERIA("DZ", "Algeria"),

	/**
	 * International key, to use for localization, for <b>American Samoa</b> region.
	 */
	AMERICAN_SAMOA("AS", "American Samoa"),

	/**
	 * International key, to use for localization, for <b>Andorra</b> region.
	 */
	ANDORRA("AD", "Andorra"),

	/**
	 * International key, to use for localization, for <b>Angola</b> region.
	 */
	ANGOLA("AO", "Angola"),

	/**
	 * International key, to use for localization, for <b>Anguilla</b> region.
	 */
	ANGUILLA("AI", "Anguilla"),

	/**
	 * International key, to use for localization, for <b>Antarctica</b> region.
	 */
	ANTARCTICA("AQ", "Antarctica"),

	/**
	 * International key, to use for localization, for <b>Antigua and Barbuda</b> region.
	 */
	ANTIGUA_AND_BARBUDA("AG", "Antigua and Barbuda"),

	/**
	 * International key, to use for localization, for <b>Argentina</b> region.
	 */
	ARGENTINA("AR", "Argentina"),

	/**
	 * International key, to use for localization, for <b>Armenia</b> region.
	 */
	ARMENIA("AM", "Armenia"),

	/**
	 * International key, to use for localization, for <b>Aruba</b> region.
	 */
	ARUBA("AW", "Aruba"),

	/**
	 * International key, to use for localization, for <b>Australia</b> region.
	 */
	AUSTRALIA("AU", "Australia"),

	/**
	 * International key, to use for localization, for <b>Austria</b> region.
	 */
	AUSTRIA("AT", "Austria"),

	/**
	 * International key, to use for localization, for <b>Azerbaijan</b> region.
	 */
	AZERBAIJAN("AZ", "Azerbaijan"),

	/**
	 * International key, to use for localization, for <b>Bahrain</b> region.
	 */
	BAHRAIN("BH", "Bahrain"),

	/**
	 * International key, to use for localization, for <b>Bailiwick of Guernsey</b> region.
	 */
	BAILIWICK_OF_GUERNSEY("GG", "Bailiwick of Guernsey"),

	/**
	 * International key, to use for localization, for <b>Bangladesh</b> region.
	 */
	BANGLADESH("BD", "Bangladesh"),

	/**
	 * International key, to use for localization, for <b>Barbados</b> region.
	 */
	BARBADOS("BB", "Barbados"),

	/**
	 * International key, to use for localization, for <b>Belarus</b> region.
	 */
	BELARUS("BY", "Belarus"),

	/**
	 * International key, to use for localization, for <b>Belgium</b> region.
	 */
	BELGIUM("BE", "Belgium"),

	/**
	 * International key, to use for localization, for <b>Belize</b> region.
	 */
	BELIZE("BZ", "Belize"),

	/**
	 * International key, to use for localization, for <b>Benin</b> region.
	 */
	BENIN("BJ", "Benin"),

	/**
	 * International key, to use for localization, for <b>Bermuda</b> region.
	 */
	BERMUDA("BM", "Bermuda"),

	/**
	 * International key, to use for localization, for <b>Bhutan</b> region.
	 */
	BHUTAN("BT", "Bhutan"),

	/**
	 * International key, to use for localization, for <b>Bolivia</b> region.
	 */
	BOLIVIA("BO", "Bolivia"),

	/**
	 * International key, to use for localization, for <b>Bosnia and Herzegovina</b> region.
	 */
	BOSNIA_AND_HERZEGOVINA("BA", "Bosnia and Herzegovina"),

	/**
	 * International key, to use for localization, for <b>Botswana</b> region.
	 */
	BOTSWANA("BW", "Botswana"),

	/**
	 * International key, to use for localization, for <b>Bouvet Island</b> region.
	 */
	BOUVET_ISLAND("BV", "Bouvet Island"),

	/**
	 * International key, to use for localization, for <b>Brazil</b> region.
	 */
	BRAZIL("BR", "Brazil"),

	/**
	 * International key, to use for localization, for <b>British Indian Ocean Territory</b> region.
	 */
	BRITISH_INDIAN_OCEAN_TERRITORY("IO", "British Indian Ocean Territory"),

	/**
	 * International key, to use for localization, for <b>British Virgin Islands</b> region.
	 */
	BRITISH_VIRGIN_ISLANDS("VG", "British Virgin Islands"),

	/**
	 * International key, to use for localization, for <b>Brunei</b> region.
	 */
	BRUNEI("BN", "Brunei"),

	/**
	 * International key, to use for localization, for <b>Bulgaria</b> region.
	 */
	BULGARIA("BG", "Bulgaria"),

	/**
	 * International key, to use for localization, for <b>Burkina Faso</b> region.
	 */
	BURKINA_FASO("BF", "Burkina Faso"),

	/**
	 * International key, to use for localization, for <b>Burundi</b> region.
	 */
	BURUNDI("BI", "Burundi"),

	/**
	 * International key, to use for localization, for <b>Cabo Verde</b> region.
	 */
	CABO_VERDE("CV", "Cabo Verde"),

	/**
	 * International key, to use for localization, for <b>Cambodia</b> region.
	 */
	CAMBODIA("KH", "Cambodia"),

	/**
	 * International key, to use for localization, for <b>Cameroon</b> region.
	 */
	CAMEROON("CM", "Cameroon"),

	/**
	 * International key, to use for localization, for <b>Canada</b> region.
	 */
	CANADA("CA", "Canada"),

	/**
	 * International key, to use for localization, for <b>Caribbean Netherlands</b> region.
	 */
	CARIBBEAN_NETHERLANDS("BQ", "Caribbean Netherlands"),

	/**
	 * International key, to use for localization, for <b>Cayman Islands</b> region.
	 */
	CAYMAN_ISLANDS("KY", "Cayman Islands"),

	/**
	 * International key, to use for localization, for <b>Central African Republic</b> region.
	 */
	CENTRAL_AFRICAN_REPUBLIC("CF", "Central African Republic"),

	/**
	 * International key, to use for localization, for <b>Chad</b> region.
	 */
	CHAD("TD", "Chad"),

	/**
	 * International key, to use for localization, for <b>Chile</b> region.
	 */
	CHILE("CL", "Chile"),

	/**
	 * International key, to use for localization, for <b>China</b> region.
	 */
	CHINA("CN", "China"),

	/**
	 * International key, to use for localization, for <b>Christmas Island</b> region.
	 */
	CHRISTMAS_ISLAND("CX", "Christmas Island"),

	/**
	 * International key, to use for localization, for <b>Cocos (Keeling) Islands</b> region.
	 */
	COCOS_KEELING_ISLANDS("CC", "Cocos (Keeling) Islands"),

	/**
	 * International key, to use for localization, for <b>Collectivity of Saint Martin</b> region.
	 */
	COLLECTIVITY_OF_SAINT_MARTIN("MF", "Collectivity of Saint Martin"),

	/**
	 * International key, to use for localization, for <b>Colombia</b> region.
	 */
	COLOMBIA("CO", "Colombia"),

	/**
	 * International key, to use for localization, for <b>Comoros</b> region.
	 */
	COMOROS("KM", "Comoros"),

	/**
	 * International key, to use for localization, for <b>Cook Islands</b> region.
	 */
	COOK_ISLANDS("CK", "Cook Islands"),

	/**
	 * International key, to use for localization, for <b>Costa Rica</b> region.
	 */
	COSTA_RICA("CR", "Costa Rica"),

	/**
	 * International key, to use for localization, for <b>Croatia</b> region.
	 */
	CROATIA("HR", "Croatia"),

	/**
	 * International key, to use for localization, for <b>Cuba</b> region.
	 */
	CUBA("CU", "Cuba"),

	/**
	 * International key, to use for localization, for <b>Curaçao</b> region.
	 */
	CURACAO("CW", "Curaçao"),

	/**
	 * International key, to use for localization, for <b>Cyprus</b> region.
	 */
	CYPRUS("CY", "Cyprus"),

	/**
	 * International key, to use for localization, for <b>Czech Republic</b> region.
	 */
	CZECH_REPUBLIC("CZ", "Czech Republic"),

	/**
	 * International key, to use for localization, for <b>Democratic Republic of the Congo</b> region.
	 */
	DEMOCRATIC_REPUBLIC_OF_THE_CONGO("CD", "Democratic Republic of the Congo"),

	/**
	 * International key, to use for localization, for <b>Denmark</b> region.
	 */
	DENMARK("DK", "Denmark"),

	/**
	 * International key, to use for localization, for <b>Djibouti</b> region.
	 */
	DJIBOUTI("DJ", "Djibouti"),

	/**
	 * International key, to use for localization, for <b>Dominica</b> region.
	 */
	DOMINICA("DM", "Dominica"),

	/**
	 * International key, to use for localization, for <b>Dominican Republic</b> region.
	 */
	DOMINICAN_REPUBLIC("DO", "Dominican Republic"),

	/**
	 * International key, to use for localization, for <b>East Timor</b> region.
	 */
	EAST_TIMOR("TL", "East Timor"),

	/**
	 * International key, to use for localization, for <b>Ecuador</b> region.
	 */
	ECUADOR("EC", "Ecuador"),

	/**
	 * International key, to use for localization, for <b>Egypt</b> region.
	 */
	EGYPT("EG", "Egypt"),

	/**
	 * International key, to use for localization, for <b>El Salvador</b> region.
	 */
	EL_SALVADOR("SV", "El Salvador"),

	/**
	 * International key, to use for localization, for <b>Equatorial Guinea</b> region.
	 */
	EQUATORIAL_GUINEA("GQ", "Equatorial Guinea"),

	/**
	 * International key, to use for localization, for <b>Eritrea</b> region.
	 */
	ERITREA("ER", "Eritrea"),

	/**
	 * International key, to use for localization, for <b>Estonia</b> region.
	 */
	ESTONIA("EE", "Estonia"),

	/**
	 * International key, to use for localization, for <b>Eswatini</b> region.
	 */
	ESWATINI("SZ", "Eswatini"),

	/**
	 * International key, to use for localization, for <b>Ethiopia</b> region.
	 */
	ETHIOPIA("ET", "Ethiopia"),

	/**
	 * International key, to use for localization, for <b>Falkland Islands</b> region.
	 */
	FALKLAND_ISLANDS("FK", "Falkland Islands"),

	/**
	 * International key, to use for localization, for <b>Faroe Islands</b> region.
	 */
	FAROE_ISLANDS("FO", "Faroe Islands"),

	/**
	 * International key, to use for localization, for <b>Federated States of Micronesia</b> region.
	 */
	FEDERATED_STATES_OF_MICRONESIA("FM", "Federated States of Micronesia"),

	/**
	 * International key, to use for localization, for <b>Fiji</b> region.
	 */
	FIJI("FJ", "Fiji"),

	/**
	 * International key, to use for localization, for <b>Finland</b> region.
	 */
	FINLAND("FI", "Finland"),

	/**
	 * International key, to use for localization, for <b>France</b> region.
	 */
	FRANCE("FR", "France"),

	/**
	 * International key, to use for localization, for <b>French Guiana</b> region.
	 */
	FRENCH_GUIANA("GF", "French Guiana"),

	/**
	 * International key, to use for localization, for <b>French Polynesia</b> region.
	 */
	FRENCH_POLYNESIA("PF", "French Polynesia"),

	/**
	 * International key, to use for localization, for <b>French Southern and Antarctic Lands</b> region.
	 */
	FRENCH_SOUTHERN_AND_ANTARCTIC_LANDS("TF", "French Southern and Antarctic Lands"),

	/**
	 * International key, to use for localization, for <b>Gabon</b> region.
	 */
	GABON("GA", "Gabon"),

	/**
	 * International key, to use for localization, for <b>Georgia (country)</b> region.
	 */
	GEORGIA("GE", "Georgia (country)"),

	/**
	 * International key, to use for localization, for <b>Germany</b> region.
	 */
	GERMANY("DE", "Germany"),

	/**
	 * International key, to use for localization, for <b>Ghana</b> region.
	 */
	GHANA("GH", "Ghana"),

	/**
	 * International key, to use for localization, for <b>Gibraltar</b> region.
	 */
	GIBRALTAR("GI", "Gibraltar"),

	/**
	 * International key, to use for localization, for <b>Greece</b> region.
	 */
	GREECE("GR", "Greece"),

	/**
	 * International key, to use for localization, for <b>Greenland</b> region.
	 */
	GREENLAND("GL", "Greenland"),

	/**
	 * International key, to use for localization, for <b>Grenada</b> region.
	 */
	GRENADA("GD", "Grenada"),

	/**
	 * International key, to use for localization, for <b>Guadeloupe</b> region.
	 */
	GUADELOUPE("GP", "Guadeloupe"),

	/**
	 * International key, to use for localization, for <b>Guam</b> region.
	 */
	GUAM("GU", "Guam"),

	/**
	 * International key, to use for localization, for <b>Guatemala</b> region.
	 */
	GUATEMALA("GT", "Guatemala"),

	/**
	 * International key, to use for localization, for <b>Guinea</b> region.
	 */
	GUINEA("GN", "Guinea"),

	/**
	 * International key, to use for localization, for <b>Guinea-Bissau</b> region.
	 */
	GUINEA_BISSAU("GW", "Guinea-Bissau"),

	/**
	 * International key, to use for localization, for <b>Guyana</b> region.
	 */
	GUYANA("GY", "Guyana"),

	/**
	 * International key, to use for localization, for <b>Haiti</b> region.
	 */
	HAITI("HT", "Haiti"),

	/**
	 * International key, to use for localization, for <b>Heard Island and McDonald Islands</b> region.
	 */
	HEARD_ISLAND_AND_MCDONALD_ISLANDS("HM", "Heard Island and McDonald Islands"),

	/**
	 * International key, to use for localization, for <b>Honduras</b> region.
	 */
	HONDURAS("HN", "Honduras"),

	/**
	 * International key, to use for localization, for <b>Hong Kong</b> region.
	 */
	HONG_KONG("HK", "Hong Kong"),

	/**
	 * International key, to use for localization, for <b>Hungary</b> region.
	 */
	HUNGARY("HU", "Hungary"),

	/**
	 * International key, to use for localization, for <b>Iceland</b> region.
	 */
	ICELAND("IS", "Iceland"),

	/**
	 * International key, to use for localization, for <b>India</b> region.
	 */
	INDIA("IN", "India"),

	/**
	 * International key, to use for localization, for <b>Indonesia</b> region.
	 */
	INDONESIA("ID", "Indonesia"),

	/**
	 * International key, to use for localization, for <b>Iran</b> region.
	 */
	IRAN("IR", "Iran"),

	/**
	 * International key, to use for localization, for <b>Iraq</b> region.
	 */
	IRAQ("IQ", "Iraq"),

	/**
	 * International key, to use for localization, for <b>Isle of Man</b> region.
	 */
	ISLE_OF_MAN("IM", "Isle of Man"),

	/**
	 * International key, to use for localization, for <b>Israel</b> region.
	 */
	ISRAEL("IL", "Israel"),

	/**
	 * International key, to use for localization, for <b>Italy</b> region.
	 */
	ITALY("IT", "Italy"),

	/**
	 * International key, to use for localization, for <b>Ivory Coast</b> region.
	 */
	IVORY_COAST("CI", "Ivory Coast"),

	/**
	 * International key, to use for localization, for <b>Jamaica</b> region.
	 */
	JAMAICA("JM", "Jamaica"),

	/**
	 * International key, to use for localization, for <b>Japan</b> region.
	 */
	JAPAN("JP", "Japan"),

	/**
	 * International key, to use for localization, for <b>Jersey</b> region.
	 */
	JERSEY("JE", "Jersey"),

	/**
	 * International key, to use for localization, for <b>Jordan</b> region.
	 */
	JORDAN("JO", "Jordan"),

	/**
	 * International key, to use for localization, for <b>Kazakhstan</b> region.
	 */
	KAZAKHSTAN("KZ", "Kazakhstan"),

	/**
	 * International key, to use for localization, for <b>Kenya</b> region.
	 */
	KENYA("KE", "Kenya"),

	/**
	 * International key, to use for localization, for <b>Kingdom of the Netherlands</b> region.
	 */
	KINGDOM_OF_THE_NETHERLANDS("NL", "Kingdom of the Netherlands"),

	/**
	 * International key, to use for localization, for <b>Kiribati</b> region.
	 */
	KIRIBATI("KI", "Kiribati"),

	/**
	 * International key, to use for localization, for <b>Kuwait</b> region.
	 */
	KUWAIT("KW", "Kuwait"),

	/**
	 * International key, to use for localization, for <b>Kyrgyzstan</b> region.
	 */
	KYRGYZSTAN("KG", "Kyrgyzstan"),

	/**
	 * International key, to use for localization, for <b>Laos</b> region.
	 */
	LAOS("LA", "Laos"),

	/**
	 * International key, to use for localization, for <b>Latvia</b> region.
	 */
	LATVIA("LV", "Latvia"),

	/**
	 * International key, to use for localization, for <b>Lebanon</b> region.
	 */
	LEBANON("LB", "Lebanon"),

	/**
	 * International key, to use for localization, for <b>Lesotho</b> region.
	 */
	LESOTHO("LS", "Lesotho"),

	/**
	 * International key, to use for localization, for <b>Liberia</b> region.
	 */
	LIBERIA("LR", "Liberia"),

	/**
	 * International key, to use for localization, for <b>Libya</b> region.
	 */
	LIBYA("LY", "Libya"),

	/**
	 * International key, to use for localization, for <b>Liechtenstein</b> region.
	 */
	LIECHTENSTEIN("LI", "Liechtenstein"),

	/**
	 * International key, to use for localization, for <b>Lithuania</b> region.
	 */
	LITHUANIA("LT", "Lithuania"),

	/**
	 * International key, to use for localization, for <b>Luxembourg</b> region.
	 */
	LUXEMBOURG("LU", "Luxembourg"),

	/**
	 * International key, to use for localization, for <b>Macau</b> region.
	 */
	MACAU("MO", "Macau"),

	/**
	 * International key, to use for localization, for <b>Madagascar</b> region.
	 */
	MADAGASCAR("MG", "Madagascar"),

	/**
	 * International key, to use for localization, for <b>Malawi</b> region.
	 */
	MALAWI("MW", "Malawi"),

	/**
	 * International key, to use for localization, for <b>Malaysia</b> region.
	 */
	MALAYSIA("MY", "Malaysia"),

	/**
	 * International key, to use for localization, for <b>Maldives</b> region.
	 */
	MALDIVES("MV", "Maldives"),

	/**
	 * International key, to use for localization, for <b>Mali</b> region.
	 */
	MALI("ML", "Mali"),

	/**
	 * International key, to use for localization, for <b>Malta</b> region.
	 */
	MALTA("MT", "Malta"),

	/**
	 * International key, to use for localization, for <b>Marshall Islands</b> region.
	 */
	MARSHALL_ISLANDS("MH", "Marshall Islands"),

	/**
	 * International key, to use for localization, for <b>Martinique</b> region.
	 */
	MARTINIQUE("MQ", "Martinique"),

	/**
	 * International key, to use for localization, for <b>Mauritania</b> region.
	 */
	MAURITANIA("MR", "Mauritania"),

	/**
	 * International key, to use for localization, for <b>Mauritius</b> region.
	 */
	MAURITIUS("MU", "Mauritius"),

	/**
	 * International key, to use for localization, for <b>Mayotte</b> region.
	 */
	MAYOTTE("YT", "Mayotte"),

	/**
	 * International key, to use for localization, for <b>Mexico</b> region.
	 */
	MEXICO("MX", "Mexico"),

	/**
	 * International key, to use for localization, for <b>Moldova</b> region.
	 */
	MOLDOVA("MD", "Moldova"),

	/**
	 * International key, to use for localization, for <b>Monaco</b> region.
	 */
	MONACO("MC", "Monaco"),

	/**
	 * International key, to use for localization, for <b>Mongolia</b> region.
	 */
	MONGOLIA("MN", "Mongolia"),

	/**
	 * International key, to use for localization, for <b>Montenegro</b> region.
	 */
	MONTENEGRO("ME", "Montenegro"),

	/**
	 * International key, to use for localization, for <b>Montserrat</b> region.
	 */
	MONTSERRAT("MS", "Montserrat"),

	/**
	 * International key, to use for localization, for <b>Morocco</b> region.
	 */
	MOROCCO("MA", "Morocco"),

	/**
	 * International key, to use for localization, for <b>Mozambique</b> region.
	 */
	MOZAMBIQUE("MZ", "Mozambique"),

	/**
	 * International key, to use for localization, for <b>Myanmar</b> region.
	 */
	MYANMAR("MM", "Myanmar"),

	/**
	 * International key, to use for localization, for <b>Namibia</b> region.
	 */
	NAMIBIA("NA", "Namibia"),

	/**
	 * International key, to use for localization, for <b>Nauru</b> region.
	 */
	NAURU("NR", "Nauru"),

	/**
	 * International key, to use for localization, for <b>Nepal</b> region.
	 */
	NEPAL("NP", "Nepal"),

	/**
	 * International key, to use for localization, for <b>New Caledonia</b> region.
	 */
	NEW_CALEDONIA("NC", "New Caledonia"),

	/**
	 * International key, to use for localization, for <b>New Zealand</b> region.
	 */
	NEW_ZEALAND("NZ", "New Zealand"),

	/**
	 * International key, to use for localization, for <b>Nicaragua</b> region.
	 */
	NICARAGUA("NI", "Nicaragua"),

	/**
	 * International key, to use for localization, for <b>Niger</b> region.
	 */
	NIGER("NE", "Niger"),

	/**
	 * International key, to use for localization, for <b>Nigeria</b> region.
	 */
	NIGERIA("NG", "Nigeria"),

	/**
	 * International key, to use for localization, for <b>Niue</b> region.
	 */
	NIUE("NU", "Niue"),

	/**
	 * International key, to use for localization, for <b>Norfolk Island</b> region.
	 */
	NORFOLK_ISLAND("NF", "Norfolk Island"),

	/**
	 * International key, to use for localization, for <b>North Korea</b> region.
	 */
	NORTH_KOREA("KP", "North Korea"),

	/**
	 * International key, to use for localization, for <b>North Macedonia</b> region.
	 */
	NORTH_MACEDONIA("MK", "North Macedonia"),

	/**
	 * International key, to use for localization, for <b>Northern Mariana Islands</b> region.
	 */
	NORTHERN_MARIANA_ISLANDS("MP", "Northern Mariana Islands"),

	/**
	 * International key, to use for localization, for <b>Norway</b> region.
	 */
	NORWAY("NO", "Norway"),

	/**
	 * International key, to use for localization, for <b>Oman</b> region.
	 */
	OMAN("OM", "Oman"),

	/**
	 * International key, to use for localization, for <b>Pakistan</b> region.
	 */
	PAKISTAN("PK", "Pakistan"),

	/**
	 * International key, to use for localization, for <b>Palau</b> region.
	 */
	PALAU("PW", "Palau"),

	/**
	 * International key, to use for localization, for <b>Panama</b> region.
	 */
	PANAMA("PA", "Panama"),

	/**
	 * International key, to use for localization, for <b>Papua New Guinea</b> region.
	 */
	PAPUA_NEW_GUINEA("PG", "Papua New Guinea"),

	/**
	 * International key, to use for localization, for <b>Paraguay</b> region.
	 */
	PARAGUAY("PY", "Paraguay"),

	/**
	 * International key, to use for localization, for <b>Peru</b> region.
	 */
	PERU("PE", "Peru"),

	/**
	 * International key, to use for localization, for <b>Philippines</b> region.
	 */
	PHILIPPINES("PH", "Philippines"),

	/**
	 * International key, to use for localization, for <b>Pitcairn Islands</b> region.
	 */
	PITCAIRN_ISLANDS("PN", "Pitcairn Islands"),

	/**
	 * International key, to use for localization, for <b>Poland</b> region.
	 */
	POLAND("PL", "Poland"),

	/**
	 * International key, to use for localization, for <b>Portugal</b> region.
	 */
	PORTUGAL("PT", "Portugal"),

	/**
	 * International key, to use for localization, for <b>Puerto Rico</b> region.
	 */
	PUERTO_RICO("PR", "Puerto Rico"),

	/**
	 * International key, to use for localization, for <b>Qatar</b> region.
	 */
	QATAR("QA", "Qatar"),

	/**
	 * International key, to use for localization, for <b>Republic of Ireland</b> region.
	 */
	REPUBLIC_OF_IRELAND("IE", "Republic of Ireland"),

	/**
	 * International key, to use for localization, for <b>Republic of the Congo</b> region.
	 */
	REPUBLIC_OF_THE_CONGO("CG", "Republic of the Congo"),

	/**
	 * International key, to use for localization, for <b>Romania</b> region.
	 */
	ROMANIA("RO", "Romania"),

	/**
	 * International key, to use for localization, for <b>Russia</b> region.
	 */
	RUSSIA("RU", "Russia"),

	/**
	 * International key, to use for localization, for <b>Rwanda</b> region.
	 */
	RWANDA("RW", "Rwanda"),

	/**
	 * International key, to use for localization, for <b>Réunion</b> region.
	 */
	REUNION("RE", "Réunion"),

	/**
	 * International key, to use for localization, for <b>Saint Barthélemy</b> region.
	 */
	SAINT_BARTHELEMY("BL", "Saint Barthélemy"),

	/**
	 * International key, to use for localization, for <b>Saint Helena, Ascension and Tristan da Cunha</b> region.
	 */
	SAINT_HELENA("SH", "Saint Helena, Ascension and Tristan da Cunha"),

	/**
	 * International key, to use for localization, for <b>Saint Kitts and Nevis</b> region.
	 */
	SAINT_KITTS_AND_NEVIS("KN", "Saint Kitts and Nevis"),

	/**
	 * International key, to use for localization, for <b>Saint Lucia</b> region.
	 */
	SAINT_LUCIA("LC", "Saint Lucia"),

	/**
	 * International key, to use for localization, for <b>Saint Pierre and Miquelon</b> region.
	 */
	SAINT_PIERRE_AND_MIQUELON("PM", "Saint Pierre and Miquelon"),

	/**
	 * International key, to use for localization, for <b>Saint Vincent and the Grenadines</b> region.
	 */
	SAINT_VINCENT_AND_THE_GRENADINES("VC", "Saint Vincent and the Grenadines"),

	/**
	 * International key, to use for localization, for <b>Samoa</b> region.
	 */
	SAMOA("WS", "Samoa"),

	/**
	 * International key, to use for localization, for <b>San Marino</b> region.
	 */
	SAN_MARINO("SM", "San Marino"),

	/**
	 * International key, to use for localization, for <b>Saudi Arabia</b> region.
	 */
	SAUDI_ARABIA("SA", "Saudi Arabia"),

	/**
	 * International key, to use for localization, for <b>Senegal</b> region.
	 */
	SENEGAL("SN", "Senegal"),

	/**
	 * International key, to use for localization, for <b>Serbia</b> region.
	 */
	SERBIA("RS", "Serbia"),

	/**
	 * International key, to use for localization, for <b>Seychelles</b> region.
	 */
	SEYCHELLES("SC", "Seychelles"),

	/**
	 * International key, to use for localization, for <b>Sierra Leone</b> region.
	 */
	SIERRA_LEONE("SL", "Sierra Leone"),

	/**
	 * International key, to use for localization, for <b>Singapore</b> region.
	 */
	SINGAPORE("SG", "Singapore"),

	/**
	 * International key, to use for localization, for <b>Sint Maarten</b> region.
	 */
	SINT_MAARTEN("SX", "Sint Maarten"),

	/**
	 * International key, to use for localization, for <b>Slovakia</b> region.
	 */
	SLOVAKIA("SK", "Slovakia"),

	/**
	 * International key, to use for localization, for <b>Slovenia</b> region.
	 */
	SLOVENIA("SI", "Slovenia"),

	/**
	 * International key, to use for localization, for <b>Solomon Islands</b> region.
	 */
	SOLOMON_ISLANDS("SB", "Solomon Islands"),

	/**
	 * International key, to use for localization, for <b>Somalia</b> region.
	 */
	SOMALIA("SO", "Somalia"),

	/**
	 * International key, to use for localization, for <b>South Africa</b> region.
	 */
	SOUTH_AFRICA("ZA", "South Africa"),

	/**
	 * International key, to use for localization, for <b>South Georgia and the South Sandwich Islands</b> region.
	 */
	SOUTH_GEORGIA_AND_THE_SOUTH_SANDWICH_ISLANDS("GS", "South Georgia and the South Sandwich Islands"),

	/**
	 * International key, to use for localization, for <b>South Korea</b> region.
	 */
	SOUTH_KOREA("KR", "South Korea"),

	/**
	 * International key, to use for localization, for <b>South Sudan</b> region.
	 */
	SOUTH_SUDAN("SS", "South Sudan"),

	/**
	 * International key, to use for localization, for <b>Spain</b> region.
	 */
	SPAIN("ES", "Spain"),

	/**
	 * International key, to use for localization, for <b>Sri Lanka</b> region.
	 */
	SRI_LANKA("LK", "Sri Lanka"),

	/**
	 * International key, to use for localization, for <b>State of Palestine</b> region.
	 */
	STATE_OF_PALESTINE("PS", "State of Palestine"),

	/**
	 * International key, to use for localization, for <b>Sudan</b> region.
	 */
	SUDAN("SD", "Sudan"),

	/**
	 * International key, to use for localization, for <b>Suriname</b> region.
	 */
	SURINAME("SR", "Suriname"),

	/**
	 * International key, to use for localization, for <b>Svalbard and Jan Mayen</b> region.
	 */
	SVALBARD_AND_JAN_MAYEN("SJ", "Svalbard and Jan Mayen"),

	/**
	 * International key, to use for localization, for <b>Sweden</b> region.
	 */
	SWEDEN("SE", "Sweden"),

	/**
	 * International key, to use for localization, for <b>Switzerland</b> region.
	 */
	SWITZERLAND("CH", "Switzerland"),

	/**
	 * International key, to use for localization, for <b>Syria</b> region.
	 */
	SYRIA("SY", "Syria"),

	/**
	 * International key, to use for localization, for <b>São Tomé and Príncipe</b> region.
	 */
	SAO_TOME_AND_PRINCIPE("ST", "São Tomé and Príncipe"),

	/**
	 * International key, to use for localization, for <b>Taiwan</b> region.
	 */
	TAIWAN("TW", "Taiwan"),

	/**
	 * International key, to use for localization, for <b>Tajikistan</b> region.
	 */
	TAJIKISTAN("TJ", "Tajikistan"),

	/**
	 * International key, to use for localization, for <b>Tanzania</b> region.
	 */
	TANZANIA("TZ", "Tanzania"),

	/**
	 * International key, to use for localization, for <b>Thailand</b> region.
	 */
	THAILAND("TH", "Thailand"),

	/**
	 * International key, to use for localization, for <b>The Bahamas</b> region.
	 */
	BAHAMAS("BS", "The Bahamas"),

	/**
	 * International key, to use for localization, for <b>The Gambia</b> region.
	 */
	GAMBIA("GM", "The Gambia"),

	/**
	 * International key, to use for localization, for <b>Togo</b> region.
	 */
	TOGO("TG", "Togo"),

	/**
	 * International key, to use for localization, for <b>Tokelau</b> region.
	 */
	TOKELAU("TK", "Tokelau"),

	/**
	 * International key, to use for localization, for <b>Tonga</b> region.
	 */
	TONGA("TO", "Tonga"),

	/**
	 * International key, to use for localization, for <b>Trinidad and Tobago</b> region.
	 */
	TRINIDAD_AND_TOBAGO("TT", "Trinidad and Tobago"),

	/**
	 * International key, to use for localization, for <b>Tunisia</b> region.
	 */
	TUNISIA("TN", "Tunisia"),

	/**
	 * International key, to use for localization, for <b>Turkey</b> region.
	 */
	TURKEY("TR", "Turkey"),

	/**
	 * International key, to use for localization, for <b>Turkmenistan</b> region.
	 */
	TURKMENISTAN("TM", "Turkmenistan"),

	/**
	 * International key, to use for localization, for <b>Turks and Caicos Islands</b> region.
	 */
	TURKS_AND_CAICOS_ISLANDS("TC", "Turks and Caicos Islands"),

	/**
	 * International key, to use for localization, for <b>Tuvalu</b> region.
	 */
	TUVALU("TV", "Tuvalu"),

	/**
	 * International key, to use for localization, for <b>Uganda</b> region.
	 */
	UGANDA("UG", "Uganda"),

	/**
	 * International key, to use for localization, for <b>Ukraine</b> region.
	 */
	UKRAINE("UA", "Ukraine"),

	/**
	 * International key, to use for localization, for <b>United Arab Emirates</b> region.
	 */
	UNITED_ARAB_EMIRATES("AE", "United Arab Emirates"),

	/**
	 * International key, to use for localization, for <b>United Kingdom</b> region.
	 */
	UNITED_KINGDOM("GB", "United Kingdom"),

	/**
	 * International key, to use for localization, for <b>United States</b> region.
	 */
	UNITED_STATES("US", "United States"),

	/**
	 * International key, to use for localization, for <b>United States Minor Outlying Islands</b> region.
	 */
	UNITED_STATES_MINOR_OUTLYING_ISLANDS("UM", "United States Minor Outlying Islands"),

	/**
	 * International key, to use for localization, for <b>United States Virgin Islands</b> region.
	 */
	UNITED_STATES_VIRGIN_ISLANDS("VI", "United States Virgin Islands"),

	/**
	 * International key, to use for localization, for <b>Uruguay</b> region.
	 */
	URUGUAY("UY", "Uruguay"),

	/**
	 * International key, to use for localization, for <b>Uzbekistan</b> region.
	 */
	UZBEKISTAN("UZ", "Uzbekistan"),

	/**
	 * International key, to use for localization, for <b>Vanuatu</b> region.
	 */
	VANUATU("VU", "Vanuatu"),

	/**
	 * International key, to use for localization, for <b>Vatican City</b> region.
	 */
	VATICAN_CITY("VA", "Vatican City"),

	/**
	 * International key, to use for localization, for <b>Venezuela</b> region.
	 */
	VENEZUELA("VE", "Venezuela"),

	/**
	 * International key, to use for localization, for <b>Vietnam</b> region.
	 */
	VIETNAM("VN", "Vietnam"),

	/**
	 * International key, to use for localization, for <b>Wallis and Futuna</b> region.
	 */
	WALLIS_AND_FUTUNA("WF", "Wallis and Futuna"),

	/**
	 * International key, to use for localization, for <b>Western Sahara</b> region.
	 */
	WESTERN_SAHARA("EH", "Western Sahara"),

	/**
	 * International key, to use for localization, for <b>Yemen</b> region.
	 */
	YEMEN("YE", "Yemen"),

	/**
	 * International key, to use for localization, for <b>Zambia</b> region.
	 */
	ZAMBIA("ZM", "Zambia"),

	/**
	 * International key, to use for localization, for <b>Zimbabwe</b> region.
	 */
	ZIMBABWE("ZW", "Zimbabwe"),

	/**
	 * International key, to use for localization, for <b>Åland Islands</b> region.
	 */
	ALAND_ISLANDS("AX", "Åland Islands");

	// value for key
	private final String value;
	// name of region
	private final String name;

	/**
	 * Creates the object with region value and its name.
	 * 
	 * @param value region identifier
	 * @param name name of the region
	 */
	private Region(String value, String name) {
		this.value = value;
		this.name = name;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.commons.Key#value()
	 */
	@Override
	public String value() {
		return value;
	}

	/**
	 * Returns the name of the region.
	 * 
	 * @return the name of the region
	 */
	@Override
	public String getName() {
		return name;
	}

}